@@ -1,12 +1,17 @@
 class Theme:
-    panel_title = "bright_blue"
+    panel_title = "default"
     heading = "bold yellow"
     table_field = "bold bright_magenta"
     table_value = "none"
+    popularity_source = "bright_cyan"
     inline_stat = "cyan"
     vendor_list = "cyan"
     nameserver_list = "cyan"
     disclaimer = "italic white on red"
+    tags = "bright_white on black"
+    product = "orange_red1"
+    port = "bright_cyan"
+    transport = "cyan"
     footer = "cyan"
     info = "bold green"
     warn = "bold yellow"
