@@ -1,6 +1,7 @@
 import sys
 
 from datetime import datetime, timedelta, timezone
+from ipaddress import ip_address
 from typing import Optional, Union
 
 from rich.text import Text
@@ -21,11 +22,17 @@ def older_than(ts: int, days: int) -> bool:
     return datetime.fromtimestamp(ts) < datetime.now() - timedelta(days=days)
 
 
-def smart_join(*items: Optional[str], style: Optional[str] = None) -> Union[Text, str]:
+def smart_join(
+    *items: Optional[Union[Text, str]],
+    style: Optional[str] = None
+) -> Union[Text, str]:
     text = Text()
     for idx, item in enumerate(items):
         if item:
-            text.append(item, style=style)
+            if isinstance(item, Text):
+                text.append(item)
+            else:
+                text.append(item, style=style)
             if idx < len(items) - 1:
                 text.append(", ", style="default")
     return text if str(text) != "" else ""
@@ -34,3 +41,16 @@ def smart_join(*items: Optional[str], style: Optional[str] = None) -> Union[Text
 def error_and_exit(message: str, status: int = 1):
     print(message, file=sys.stderr)
     raise SystemExit(status)
+
+
+def refang(text: str) -> str:
+    """ Strip []s out of text """
+    return text.replace("[", "").replace("]", "")
+
+
+def is_ip(text: str) -> bool:
+    """ Detect whether text is IPv4 or not """
+    try:
+        return ip_address(refang(text)).is_global
+    except ValueError:
+        return False
